@@ -1,7 +1,7 @@
 package App::lcpan::Call;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2015-10-20'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -23,6 +23,7 @@ $SPEC{call_lcpan_script} = {
             default => [],
         },
     },
+    result_naked => 1,
 };
 sub call_lcpan_script {
     require Perinci::CmdLine::Call;
@@ -71,7 +72,7 @@ App::lcpan::Call - "Call" lcpan script
 
 =head1 VERSION
 
-This document describes version 0.03 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2015-09-03.
+This document describes version 0.04 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2015-10-20.
 
 =head1 FUNCTIONS
 
@@ -80,6 +81,8 @@ This document describes version 0.03 of App::lcpan::Call (from Perl distribution
 
 "Call" lcpan script.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
